.. _spkg_python_json_logger:

python_json_logger: Python library adding a json log formatter
========================================================================

Description
-----------

Python library adding a json log formatter

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/python-json-logger/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    2.0.7

version_requirements.txt::

    python-json-logger


Equivalent System Packages
--------------------------

(none known)

